==> StenLib-0.7.5.tar.gz: StenLib-0.7.5/README.md <==
<a name="readme-top"></a>

<div align="center">

[![Contributors][contributors-shield]][contributors-url]
[![Issues][issues-shield]][issues-url]
[![License][license-shield]][license-url]
[![Roadmap][roadmap-shield]][roadmap-url]

</div>
<div align="center">

[![Release][release-shield]][release-url]
[![Pytest][pytest-shield]][pytest-url]
[![PyPI][pypi-shield]][pypi-url]
[![Documentation][documentation-shield]][documentation-url]
[![Code Quality][codequality-shield]][codequality-url]

</div>

<br />
<div align="center">
  <a href="https://github.com/Structura-Engineering/StenLib">
    <img src=".github/images/favicon.ico" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">StenLib</h3>

  <p align="center">
    Library with premade methods for optimal coding production.
    <br />
    <a href="https://docs.structura-engineering.com"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Structura-Engineering/StenLib">Samples</a>
    ·
    <a href="https://github.com/Structura-Engineering/StenLib/issues">Report Bug</a>
    ·
    <a href="https://github.com/Structura-Engineering/StenLib/issues">Request Feature</a>
  </p>
</div>

<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
  </ol>
</details>

## About The Project

StenLib is not just a Python library; it's your companion in crafting efficient and maintainable code. Built to simplify the coding journey, StenLib offers a rich array of pre-made methods, empowering developers to focus on creating remarkable projects that tackle real-world challenges.

Whether you're a seasoned coder or just embarking on your programming adventure, StenLib strives to be your ultimate coding ally. Say goodbye to repetitive tasks and embrace best coding practices, letting StenLib pave the way for a seamless development experience.

Why StenLib?

- **Maximize Your Creativity:** Your time is valuable. StenLib frees you from mundane tasks, enabling you to channel your creativity into building extraordinary solutions.

- **Banish Repetition:** Don't waste time reinventing the wheel. StenLib encourages you to break free from repetitive tasks, ensuring you spend more time on what truly matters.

- **DRY Principles for Life:** Implement the Don't Repeat Yourself (DRY) mantra not only in your code but in your entire development process. StenLib is your guide to a more efficient and enjoyable coding life. 😊

As the coding landscape evolves, so will StenLib. Expect ongoing updates and improvements to cater to diverse project needs. Your feedback, suggestions, and contributions are highly valued, let's make StenLib even better together.

Feel free to dive into the documentation to kickstart your journey with StenLib.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Built With

This section lists the key technologies and libraries that were used in the development of this project.

- [![Docker][docker-shield]][Docker-url]
- [![Python][python-shield]][Python-url]

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Getting Started

Ready to kick off your coding journey with StenLib? Let's set up your local environment in a few simple steps:

### Prerequisites

Ensure you have the following tools installed:

- [Docker Desktop](https://www.docker.com/products/docker-desktop/)

### Installation

Follow these straightforward steps to get StenLib up and running on your local machine:

1. **Clone the Repository:**
   ```sh
   git clone https://github.com/Structura-Engineering/StenLib.git
   ```
2. **Navigate to the Project Directory**

3. **Set up the Development Container:**
   - If prompted, click on the `Reopen in Container` button at the bottom right.
   - The editor will automatically set up the development container for you.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## License

Distributed under the AGPL-3.0 License. See `LICENSE.md` for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

[contributors-shield]: https://img.shields.io/github/contributors/Structura-Engineering/StenLib?style=for-the-badge&color=blue
[contributors-url]: https://github.com/Structura-Engineering/StenLib/graphs/contributors
[issues-shield]: https://img.shields.io/github/issues/Structura-Engineering/StenLib?style=for-the-badge&color=yellow
[issues-url]: https://github.com/Structura-Engineering/StenLib/issues
[license-shield]: https://img.shields.io/github/license/Structura-Engineering/StenLib?style=for-the-badge&color=green
[license-url]: https://github.com/Structura-Engineering/StenLib/blob/master/LICENSE.md
[roadmap-shield]: https://img.shields.io/badge/Roadmap-Click%20Me!-purple.svg?style=for-the-badge
[roadmap-url]: https://github.com/orgs/Structura-Engineering/projects/2
[docker-shield]: https://img.shields.io/badge/Docker-2496ED?style=for-the-badge&logo=docker&logoColor=white
[docker-url]: https://docker.com/
[python-shield]: https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white
[python-url]: https://python.org/
[release-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/release_badge.json
[release-url]: https://github.com/Structura-Engineering/StenLib/releases
[pytest-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/pytest_badge.json
[pytest-url]: https://github.com/Structura-Engineering/StenLib/actions
[pypi-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/pypi_badge.json
[pypi-url]: https://pypi.org/project/StenLib/
[documentation-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/docs_badge.json
[documentation-url]: https://docs.structura-engineering.com
[codequality-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/code_quality_badge.json
[codequality-url]: -

==> StenLib-1.0.1.tar.gz: StenLib-1.0.1/README.md <==
<a name="readme-top"></a>

<div align="center">

[![Contributors][contributors-shield]][contributors-url]
[![Issues][issues-shield]][issues-url]
[![License][license-shield]][license-url]
[![Roadmap][roadmap-shield]][roadmap-url]

</div>
<div align="center">

[![Release][release-shield]][release-url]
[![Pytest][pytest-shield]][pytest-url]
[![PyPI][pypi-shield]][pypi-url]
[![Documentation][documentation-shield]][documentation-url]
[![Code Quality][codequality-shield]][codequality-url]

</div>

<br />
<div align="center">
  <a href="https://github.com/Structura-Engineering/StenLib">
    <img src=".github/images/favicon.ico" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">StenLib</h3>

  <p align="center">
    Library with premade methods for optimal coding production.
    <br />
    <a href="https://docs.structura-engineering.com"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Structura-Engineering/StenLib">Samples</a>
    ·
    <a href="https://github.com/Structura-Engineering/StenLib/issues">Report Bug</a>
    ·
    <a href="https://github.com/Structura-Engineering/StenLib/issues">Request Feature</a>
  </p>
</div>

<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
  </ol>
</details>

## About The Project

StenLib is not just a Python library; it's your companion in crafting efficient and maintainable code. Built to simplify the coding journey, StenLib offers a rich array of pre-made methods, empowering developers to focus on creating remarkable projects that tackle real-world challenges.

Whether you're a seasoned coder or just embarking on your programming adventure, StenLib strives to be your ultimate coding ally. Say goodbye to repetitive tasks and embrace best coding practices, letting StenLib pave the way for a seamless development experience.

Why StenLib?

- **Maximize Your Creativity:** Your time is valuable. StenLib frees you from mundane tasks, enabling you to channel your creativity into building extraordinary solutions.

- **Banish Repetition:** Don't waste time reinventing the wheel. StenLib encourages you to break free from repetitive tasks, ensuring you spend more time on what truly matters.

- **DRY Principles for Life:** Implement the Don't Repeat Yourself (DRY) mantra not only in your code but in your entire development process. StenLib is your guide to a more efficient and enjoyable coding life. 😊

As the coding landscape evolves, so will StenLib. Expect ongoing updates and improvements to cater to diverse project needs. Your feedback, suggestions, and contributions are highly valued, let's make StenLib even better together.

Feel free to dive into the documentation to kickstart your journey with StenLib.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Built With

This section lists the key technologies and libraries that were used in the development of this project.

- [![Docker][docker-shield]][docker-url]
- [![Python][python-shield]][python-url]

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Getting Started

Ready to kick off your coding journey with StenLib? Let's set up your local environment in a few simple steps:

### Prerequisites

Ensure you have the following tools installed:

- [Docker Desktop](https://www.docker.com/products/docker-desktop/)

### Installation

Follow these straightforward steps to get StenLib up and running on your local machine:

1. **Clone the Repository:**
   ```sh
   git clone https://github.com/Structura-Engineering/StenLib.git
   ```
2. **Navigate to the Project Directory**

3. **Set up the Development Container:**
   - If prompted, click on the `Reopen in Container` button at the bottom right.
   - The editor will automatically set up the development container for you.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## License

Distributed under the AGPL-3.0 License. See `LICENSE.md` for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

[contributors-shield]: https://img.shields.io/github/contributors/Structura-Engineering/StenLib?style=for-the-badge&color=blue
[contributors-url]: https://github.com/Structura-Engineering/StenLib/graphs/contributors
[issues-shield]: https://img.shields.io/github/issues/Structura-Engineering/StenLib?style=for-the-badge&color=yellow
[issues-url]: https://github.com/Structura-Engineering/StenLib/issues
[license-shield]: https://img.shields.io/github/license/Structura-Engineering/StenLib?style=for-the-badge&color=green
[license-url]: https://github.com/Structura-Engineering/StenLib/blob/master/LICENSE.md
[roadmap-shield]: https://img.shields.io/badge/Roadmap-Click%20Me!-purple.svg?style=for-the-badge
[roadmap-url]: https://github.com/orgs/Structura-Engineering/projects/2
[docker-shield]: https://img.shields.io/badge/Docker-2496ED?style=for-the-badge&logo=docker&logoColor=white
[docker-url]: https://docker.com/
[python-shield]: https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white
[python-url]: https://python.org/
[release-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/release_badge.json
[release-url]: https://github.com/Structura-Engineering/StenLib/releases
[pytest-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/pytest_badge.json
[pytest-url]: https://github.com/Structura-Engineering/StenLib/actions
[pypi-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/pypi_badge.json
[pypi-url]: https://pypi.org/project/StenLib/
[documentation-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/docs_badge.json
[documentation-url]: https://docs.structura-engineering.com
[codequality-shield]: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/illyrius666/27fc61b978a42aea3bb569da8416b3e6/raw/code_quality_badge.json
[codequality-url]: -
